@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-09-29'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2015-10-06'; # DATE
+our $VERSION = '0.47'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -63,10 +63,13 @@ sub _process_module {
         for my $funcname (keys %$cmetas) {
             next unless $funcname =~ /\A\w+\z/;
             my $funcmeta = $cmetas->{$funcname};
-            my $export = 0;
+            my $export = -1;
             if ($uses_exporter_mod &&
                     grep {$_ eq $funcname} @{"$package\::EXPORT"}) {
                 $export = 1;
+            } elsif ($uses_exporter_mod &&
+                    grep {$_ eq $funcname} @{"$package\::EXPORT_OK"}) {
+                $export = 0;
             } elsif ($uses_exporter_mod) {
                 $export = -1;
             } elsif (grep {$_ eq 'export:default'} @{ $funcmeta->{tags} // [] }) {
@@ -667,7 +670,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.46 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-09-29.
+This document describes version 0.47 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-10-06.
 
 =head1 SYNOPSIS
 
